@@ -1,12 +1,12 @@
 """Write me."""
 
-__version__ = "1.1"
+__version__ = "1.2.0"
 
-from . import core
-from . import ode
-from . import utils
+# Local code
+from . import core, ode, utils
 
 try:
+    # Third party
     import modelbase_pde as pde
 except ImportError:
     pass
