@@ -1,10 +1,11 @@
 """Compound mixin."""
 
+# Standard Library
 import warnings
-from dataclasses import field
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 
-from .utils import warning_on_one_line, convert_id_to_sbml
+# Local code
+from .utils import convert_id_to_sbml, warning_on_one_line
 
 warnings.formatwarning = warning_on_one_line
 
@@ -36,7 +37,9 @@ class CompoundMixin:
     ##########################################################################
 
     def add_compound(
-        self, compound, **meta_info,
+        self,
+        compound,
+        **meta_info,
     ):
         """Add a compound to the model.
 
@@ -57,9 +60,7 @@ class CompoundMixin:
                 warnings.warn(f"Overwriting compound {compound}")
                 self.remove_compound(compound=compound)
             self.compounds.append(compound)
-            self.meta_info.setdefault("compounds", {}).setdefault(
-                compound, Compound(**meta_info)
-            )
+            self.meta_info.setdefault("compounds", {}).setdefault(compound, Compound(**meta_info))
 
     def add_compounds(self, compounds, meta_info=None):
         """Add multiple compounds to the model.
