@@ -1,15 +1,18 @@
 """Mixin for rates."""
 
+# Standard Library
 import warnings
-import libsbml as libsbml
 from collections import defaultdict
-from dataclasses import field
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 
+# Third party
+import libsbml as libsbml
+
+# Local code
 from .utils import (
+    convert_id_to_sbml,
     get_formatted_function_source_code,
     patch_lambda_function_name,
-    convert_id_to_sbml,
     warning_on_one_line,
 )
 
@@ -348,8 +351,7 @@ class RateMixin:
         arguments : list(str)
         """
         return list(
-            self.get_rate_dynamic_variables(rate_name=rate_name)
-            + self.get_rate_parameters(rate_name=rate_name)
+            self.get_rate_dynamic_variables(rate_name=rate_name) + self.get_rate_parameters(rate_name=rate_name)
         )
 
     ##########################################################################
