@@ -1,16 +1,20 @@
 """LabelModel base class."""
 
-import warnings
+# Standard Library
 import itertools as it
-import numpy as np
-import pandas as pd
-import libsbml
+import warnings
 from collections import defaultdict as _defaultdict
 
-from .model import Model
+# Third party
+import libsbml
+import numpy as np
+import pandas as pd
+
+# Local code
 from ...core.compoundmixin import Compound
 from ...core.ratemixin import Rate
-from ...core.utils import warning_on_one_line, convert_id_to_sbml
+from ...core.utils import convert_id_to_sbml, warning_on_one_line
+from .model import Model
 
 warnings.formatwarning = warning_on_one_line
 
@@ -74,10 +78,7 @@ class LabelModel(Model):
         ['cpd__00', 'cpd__01', 'cpd__10', 'cpd__11']
         """
         if num_labels > 0:
-            return [
-                base_name + "__" + "".join(i)
-                for i in it.product(("0", "1"), repeat=num_labels)
-            ]
+            return [base_name + "__" + "".join(i) for i in it.product(("0", "1"), repeat=num_labels)]
         else:
             return [base_name]
 
@@ -105,9 +106,7 @@ class LabelModel(Model):
             "num_labels": num_labels,
             "isotopomers": label_names,
         }
-        self.meta_info.setdefault("compounds", {}).setdefault(
-            base_compound, Compound(**meta_info)
-        )
+        self.meta_info.setdefault("compounds", {}).setdefault(base_compound, Compound(**meta_info))
 
     def _add_isotopomers(self, base_compound, label_names):
         # Add all labelled compounds
@@ -149,9 +148,7 @@ class LabelModel(Model):
         if num_labels == 0:
             self.add_compound(compound=compound, is_isotopomer=False, **meta_info)
         else:
-            label_names = self._generate_binary_labels(
-                base_name=compound, num_labels=num_labels
-            )
+            label_names = self._generate_binary_labels(base_name=compound, num_labels=num_labels)
             self._add_base_compound(
                 base_compound=compound,
                 num_labels=num_labels,
@@ -271,9 +268,7 @@ class LabelModel(Model):
         ]
         return [f"{compound}__{''.join(i)}" for i in label_patterns]
 
-    def get_compound_isotopomer_with_label_position(
-        self, base_compound, label_position
-    ):
+    def get_compound_isotopomer_with_label_position(self, base_compound, label_position):
         """Get compound isotopomer with a given label position.
 
         Parameters
@@ -291,8 +286,7 @@ class LabelModel(Model):
         if isinstance(label_position, int):
             label_position = [label_position]
         return f"{base_compound}__" + "".join(
-            "1" if idx in label_position else "0"
-            for idx in range(self.label_compounds[base_compound]["num_labels"])
+            "1" if idx in label_position else "0" for idx in range(self.label_compounds[base_compound]["num_labels"])
         )
 
     @staticmethod
@@ -387,9 +381,7 @@ class LabelModel(Model):
                 labels_per_compound.append(self.label_compounds[compound]["num_labels"])
             except KeyError:
                 if compound not in self.get_compounds():
-                    raise KeyError(
-                        f"Compound {compound} neither a compound nor a label compound"
-                    )
+                    raise KeyError(f"Compound {compound} neither a compound nor a label compound")
                 labels_per_compound.append(0)
         return labels_per_compound
 
@@ -491,13 +483,9 @@ class LabelModel(Model):
         )
         """
         if compounds is not None:
-            compounds = [
-                i + "__total" if i in self.label_compounds else i for i in compounds
-            ]
+            compounds = [i + "__total" if i in self.label_compounds else i for i in compounds]
         if modifiers is not None:
-            modifiers = [
-                i + "__total" if i in self.label_compounds else i for i in modifiers
-            ]
+            modifiers = [i + "__total" if i in self.label_compounds else i for i in modifiers]
         super().add_algebraic_module(
             module_name=module_name,
             function=function,
@@ -507,9 +495,7 @@ class LabelModel(Model):
             parameters=parameters,
         )
 
-    def _get_external_labels(
-        self, rate_name, total_product_labels, total_substrate_labels, external_labels
-    ):
+    def _get_external_labels(self, rate_name, total_product_labels, total_substrate_labels, external_labels):
         n_external_labels = total_product_labels - total_substrate_labels
         if n_external_labels > 0:
             if not external_labels:
@@ -565,30 +551,18 @@ class LabelModel(Model):
         labels_per_product,
     ):
         variants = []
-        for rate_suffix in (
-            "".join(i) for i in it.product(("0", "1"), repeat=total_substrate_labels)
-        ):
+        for rate_suffix in ("".join(i) for i in it.product(("0", "1"), repeat=total_substrate_labels)):
             rate_suffix += external_labels
             # This is the magic
-            product_suffix = self._map_substrates_to_products(
-                rate_suffix=rate_suffix, labelmap=labelmap
-            )
-            product_labels = self._split_label_string(
-                label=product_suffix, labels_per_compound=labels_per_product
-            )
-            substrate_labels = self._split_label_string(
-                label=rate_suffix, labels_per_compound=labels_per_substrate
-            )
+            product_suffix = self._map_substrates_to_products(rate_suffix=rate_suffix, labelmap=labelmap)
+            product_labels = self._split_label_string(label=product_suffix, labels_per_compound=labels_per_product)
+            substrate_labels = self._split_label_string(label=rate_suffix, labels_per_compound=labels_per_substrate)
 
             new_substrates = self._assign_compound_labels(
                 base_compounds=base_substrates, label_suffixes=substrate_labels
             )
-            new_products = self._assign_compound_labels(
-                base_compounds=base_products, label_suffixes=product_labels
-            )
-            new_stoichiometry = self._repack_stoichiometries(
-                new_substrates=new_substrates, new_products=new_products
-            )
+            new_products = self._assign_compound_labels(base_compounds=base_products, label_suffixes=product_labels)
+            new_stoichiometry = self._repack_stoichiometries(new_substrates=new_substrates, new_products=new_products)
             new_rate_name = rate_name + "__" + rate_suffix
             self.add_reaction(
                 rate_name=new_rate_name,
@@ -658,9 +632,7 @@ class LabelModel(Model):
             )
         """
         if modifiers is not None:
-            modifiers = [
-                i + "__total" if i in self.label_compounds else i for i in modifiers
-            ]
+            modifiers = [i + "__total" if i in self.label_compounds else i for i in modifiers]
 
         base_substrates, base_products = self._unpack_stoichiometries(stoichiometry)
         labels_per_substrate = self._get_labels_per_compound(compounds=base_substrates)
@@ -669,9 +641,7 @@ class LabelModel(Model):
         total_product_labels = sum(labels_per_product)
 
         if len(labelmap) - total_substrate_labels < 0:
-            raise ValueError(
-                f"Labelmap 'missing' {abs(len(labelmap) - total_substrate_labels)} label(s)"
-            )
+            raise ValueError(f"Labelmap 'missing' {abs(len(labelmap) - total_substrate_labels)} label(s)")
 
         external_labels = self._get_external_labels(
             rate_name=rate_name,
@@ -825,9 +795,7 @@ class LabelModel(Model):
             label_position = label_positions.get(base_compound, None)
             if label_position is None:
                 try:
-                    y0[
-                        self.label_compounds[base_compound]["isotopomers"][0]
-                    ] = concentration
+                    y0[self.label_compounds[base_compound]["isotopomers"][0]] = concentration
                 except KeyError:  # non label compound
                     y0[base_compound] = concentration
             else:
@@ -868,9 +836,7 @@ class LabelModel(Model):
         labelled_compounds : set(str)
         """
         initial_labels = [
-            self.get_compound_isotopomer_with_label_position(
-                base_compound=base_compound, label_position=label_position
-            )
+            self.get_compound_isotopomer_with_label_position(base_compound=base_compound, label_position=label_position)
             for base_compound, label_position in initial_labels.items()
         ]
 
@@ -905,9 +871,7 @@ class LabelModel(Model):
         >>> l.get_label_scope({"x": 0})
         >>> l.get_label_scope({"x": [0, 1], "y": 0})
         """
-        labelled_compounds = self._create_label_scope_seed(
-            initial_labels=initial_labels
-        )
+        labelled_compounds = self._create_label_scope_seed(initial_labels=initial_labels)
         new_labels = set("non empty entry to not fulfill while condition")
         # Loop until no new labels are inserted
         loop_count = 0
@@ -973,27 +937,19 @@ class LabelModel(Model):
         for module_name, module in self.algebraic_modules.items():
             if not module_name.endswith("__total"):
                 module = module.copy()
-                module["compounds"] = [
-                    self._map_label_compound_to_compound(i) for i in module["compounds"]
-                ]
+                module["compounds"] = [self._map_label_compound_to_compound(i) for i in module["compounds"]]
                 module["derived_compounds"] = [
-                    self._map_label_compound_to_compound(i)
-                    for i in module["derived_compounds"]
-                ]
-                module["modifiers"] = [
-                    self._map_label_compound_to_compound(i) for i in module["modifiers"]
+                    self._map_label_compound_to_compound(i) for i in module["derived_compounds"]
                 ]
+                module["modifiers"] = [self._map_label_compound_to_compound(i) for i in module["modifiers"]]
                 m.add_algebraic_module(module_name=module_name, **module)
 
         for rate_name, reaction in self.base_reactions.items():
             reaction = reaction.copy()
             reaction["stoichiometry"] = {
-                self._map_label_compound_to_compound(k): v
-                for k, v in reaction["stoichiometry"].items()
+                self._map_label_compound_to_compound(k): v for k, v in reaction["stoichiometry"].items()
             }
-            reaction["modifiers"] = [
-                self._map_label_compound_to_compound(i) for i in reaction["modifiers"]
-            ]
+            reaction["modifiers"] = [self._map_label_compound_to_compound(i) for i in reaction["modifiers"]]
             del reaction["labelmap"]
             del reaction["external_labels"]
             del reaction["variants"]
@@ -1004,9 +960,7 @@ class LabelModel(Model):
     # SBML functions
     ##########################################################################
 
-    def _add_sbml_compound(
-        self, sbml_model, compound_id, common_name, compartment, charge, formula
-    ):
+    def _add_sbml_compound(self, sbml_model, compound_id, common_name, compartment, charge, formula):
         cpd = sbml_model.createSpecies()
         cpd.setId(convert_id_to_sbml(id_=compound_id, prefix="CPD"))
         if common_name is not None:
