@@ -1,10 +1,14 @@
 """LinearLabelModel base class."""
 
+# Standard Library
 import warnings
+
+# Third party
+import libsbml
 import numpy as np
 import pandas as pd
-import libsbml
 
+# Local code
 from ...core import BaseModel, CompoundMixin, RateMixin, StoichiometricMixin
 from ...core.ratemixin import Rate
 from ...core.utils import convert_id_to_sbml
@@ -18,9 +22,7 @@ def relative_label_flux(substrate, v_ss):
 class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel):
     """LinearLabelModel."""
 
-    def __init__(
-        self, compounds=None, rate_stoichiometries=None, rates=None, meta_info=None
-    ):
+    def __init__(self, compounds=None, rate_stoichiometries=None, rates=None, meta_info=None):
         self.isotopomers = {}
         self.base_rates = {}
         BaseModel.__init__(self, meta_info=meta_info)
@@ -54,9 +56,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
             self.remove_compound(compound=compound)
             warnings.warn(f"Overwriting compound {compound}")
 
-        label_names = self._generate_isotope_labels(
-            base_name=compound, num_labels=num_labels
-        )
+        label_names = self._generate_isotope_labels(base_name=compound, num_labels=num_labels)
         self.isotopomers[compound] = label_names
 
         # Add all labelled compounds
@@ -184,14 +184,10 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
             products=products,
             labelmap=labelmap,
         )
-        substrates = self._map_substrates_to_labelmap(
-            substrates=substrates, labelmap=labelmap
-        )
+        substrates = self._map_substrates_to_labelmap(substrates=substrates, labelmap=labelmap)
 
         for i, (substrate, product) in enumerate(zip(substrates, products)):
-            self.add_stoichiometry(
-                rate_name=f"{rate_name}__{i}", stoichiometry={substrate: -1, product: 1}
-            )
+            self.add_stoichiometry(rate_name=f"{rate_name}__{i}", stoichiometry={substrate: -1, product: 1})
             self.add_rate(
                 rate_name=f"{rate_name}__{i}",
                 base_name=rate_name,
@@ -241,9 +237,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
 
         fluxes = {}
         for name, rate in self.rates.items():
-            fluxes[name] = relative_label_flux(
-                y[rate["substrate"]], v_ss[rate["base_name"]]
-            )
+            fluxes[name] = relative_label_flux(y[rate["substrate"]], v_ss[rate["base_name"]])
         return fluxes
 
     def get_fluxes_dict(self, y, v_ss, external_label=1, t=0):
@@ -274,14 +268,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         -------
         fluxes : numpy.array
         """
-        return np.array(
-            [
-                i
-                for i in self.get_fluxes_dict(
-                    y=y, v_ss=v_ss, external_label=external_label
-                ).values()
-            ]
-        ).T
+        return np.array([i for i in self.get_fluxes_dict(y=y, v_ss=v_ss, external_label=external_label).values()]).T
 
     def get_fluxes_df(self, y, v_ss, external_label=1, t=0):
         """Calculate the fluxest.
@@ -298,9 +285,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         if isinstance(t, (int, float)):
             t = [t]
         return pd.DataFrame(
-            data=self.get_fluxes_dict(
-                y=y, v_ss=v_ss, external_label=external_label, t=t
-            ),
+            data=self.get_fluxes_dict(y=y, v_ss=v_ss, external_label=external_label, t=t),
             index=t,
             columns=self.get_rate_names(),
         )
@@ -309,14 +294,10 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         y_labels = dict(zip(self.compounds, y_labels))
         dxdt = {i: 0 for i in y_labels}
 
-        fluxes = self._get_fluxes(
-            y=y_labels, v_ss=self._v_ss, external_label=self._external_label
-        )
+        fluxes = self._get_fluxes(y=y_labels, v_ss=self._v_ss, external_label=self._external_label)
         for compound, isotopomers in self.isotopomers.items():
             for isotomoper in isotopomers:
-                for rate, stoich in self.stoichiometries_by_compounds[
-                    isotomoper
-                ].items():
+                for rate, stoich in self.stoichiometries_by_compounds[isotomoper].items():
                     dxdt[isotomoper] += stoich * fluxes[rate] / self._y_ss[compound]
         return list(dxdt.values())
 
