@@ -3,21 +3,24 @@
 Description of the module
 """
 
+# Standard Library
 import subprocess
-import numpy as np
-import pandas as pd
-import libsbml
 import warnings
 
+# Third party
+import libsbml
+import numpy as np
+import pandas as pd
+
+# Local code
 from ...core import (
+    AlgebraicMixin,
     BaseModel,
     CompoundMixin,
     ParameterMixin,
-    AlgebraicMixin,
-    StoichiometricMixin,
     RateMixin,
+    StoichiometricMixin,
 )
-
 from ...core.utils import convert_id_to_sbml
 
 
@@ -282,9 +285,7 @@ class Model(
         """
         self._update_derived_parameters()
         y = self.get_full_concentration_dict(y=y, t=t)
-        return {
-            k: np.ones(len(y["time"])) * v for k, v in self._get_fluxes(y=y).items()
-        }
+        return {k: np.ones(len(y["time"])) * v for k, v in self._get_fluxes(y=y).items()}
 
     def get_fluxes_array(self, y, t=0):
         """Calculate the fluxes at time point(s) t.
@@ -314,9 +315,7 @@ class Model(
         """
         if isinstance(t, (int, float)):
             t = [t]
-        return pd.DataFrame(
-            data=self.get_fluxes_dict(y=y, t=t), index=t, columns=self.get_rate_names()
-        )
+        return pd.DataFrame(data=self.get_fluxes_dict(y=y, t=t), index=t, columns=self.get_rate_names())
 
     def _get_rhs(self, t, y):
         """Calculate the right hand side of the ODE system.
@@ -393,15 +392,14 @@ class Model(
         >>> labelmaps = {"TPI": [2, 1, 0]}
         >>> m.to_labelmodel(labelcompounds=labelcompounds, labelmaps=labelmaps)
         """
+        # Third party
         from modelbase.ode import LabelModel
 
         lm = LabelModel()
         lm.add_parameters(self.parameters)
         for compound in self.get_compounds():
             if compound in labelcompounds:
-                lm.add_label_compound(
-                    compound=compound, num_labels=labelcompounds[compound]
-                )
+                lm.add_label_compound(compound=compound, num_labels=labelcompounds[compound])
             else:
                 lm.add_compound(compound=compound)
 
@@ -473,6 +471,7 @@ class Model(
         >>> labelmaps = {"TPI_fwd": [2, 1, 0], 'TPI_bwd': [2, 1, 0]}
         >>> m.to_linear_labelmodel(labelcompounds=labelcompounds, labelmaps=labelmaps)
         """
+        # Third party
         from modelbase.ode import LinearLabelModel
 
         lm = LinearLabelModel()
@@ -489,11 +488,7 @@ class Model(
                     )
                 lm.add_reaction(
                     rate_name=rate_name,
-                    stoichiometry={
-                        k: v
-                        for k, v in self.stoichiometries[rate_name].items()
-                        if k in labelcompounds
-                    },
+                    stoichiometry={k: v for k, v in self.stoichiometries[rate_name].items() if k in labelcompounds},
                     labelmap=labelmaps[rate_name],
                 )
             else:
@@ -519,18 +514,10 @@ class Model(
         -------
         model_source_code : str
         """
-        parameters = self._generate_parameters_source_code(
-            include_meta_info=include_meta_info
-        )
-        compounds = self._generate_compounds_source_code(
-            include_meta_info=include_meta_info
-        )
-        module_functions, modules = self._generate_algebraic_modules_source_code(
-            include_meta_info=include_meta_info
-        )
-        rate_functions, rates = self._generate_rates_source_code(
-            include_meta_info=include_meta_info
-        )
+        parameters = self._generate_parameters_source_code(include_meta_info=include_meta_info)
+        compounds = self._generate_compounds_source_code(include_meta_info=include_meta_info)
+        module_functions, modules = self._generate_algebraic_modules_source_code(include_meta_info=include_meta_info)
+        rate_functions, rates = self._generate_rates_source_code(include_meta_info=include_meta_info)
         stoichiometries = self._generate_stoichiometries_source_code()
 
         model_string = "\n".join(
@@ -547,9 +534,7 @@ class Model(
             )
         )
         if linted:
-            blacked_string = subprocess.run(
-                ["black", "-c", model_string], stdout=subprocess.PIPE
-            )
+            blacked_string = subprocess.run(["black", "-c", model_string], stdout=subprocess.PIPE)
             return blacked_string.stdout.decode("utf-8")
         else:
             return model_string
