@@ -1,19 +1,25 @@
 """Write me."""
 
-import itertools as it
+# Standard Library
 import concurrent.futures as futures
-import warnings
+import copy
+import itertools as it
 import sys as sys
+import warnings
+from functools import partial
+
+# Third party
+import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-import matplotlib.pyplot as plt
-import copy
-from functools import partial
+
+# Local code
+from ...core.utils import warning_on_one_line
+from ...utils.plotting import _get_plot_kwargs, _style_subplot, plot, plot_grid
+from .basesimulator import _BaseSimulator
+
 from mpl_toolkits.mplot3d import Axes3D as _Axes3D  # flake8: NOQA
 
-from .basesimulator import _BaseSimulator
-from ...utils.plotting import plot_grid, plot, _get_plot_kwargs, _style_subplot
-from ...core.utils import warning_on_one_line
 
 warnings.formatwarning = warning_on_one_line
 
@@ -30,7 +36,10 @@ class _Simulate(_BaseSimulator):
         """Pickle this class."""
         return (
             self.__class__,
-            (self.model, self.integrator_name,),
+            (
+                self.model,
+                self.integrator_name,
+            ),
             (
                 ("y0", self.y0),
                 ("time", self.time),
@@ -44,9 +53,7 @@ class _Simulate(_BaseSimulator):
         new = copy.deepcopy(self)
         new.simulation_parameters = self.simulation_parameters.copy()
         if new.results is not None:
-            new._initialise_integrator(
-                y0=new.results[-1], integrator_name=new.integrator_name
-            )
+            new._initialise_integrator(y0=new.results[-1])
         elif new.y0 is not None:
             new.initialise(y0=new.y0, test_run=False)
         return new
@@ -85,9 +92,7 @@ class _Simulate(_BaseSimulator):
         --------
         update_parameters
         """
-        self.model.update_parameter(
-            parameter_name=parameter_name, parameter_value=parameter_value
-        )
+        self.model.update_parameter(parameter_name=parameter_name, parameter_value=parameter_value)
 
     def update_parameters(self, parameters):
         """Update existing model parameters.
@@ -104,9 +109,7 @@ class _Simulate(_BaseSimulator):
         self.model.update_parameters(parameters=parameters)
 
     def _save_simulation_results(self, time, results, skipfirst):
-        super()._save_simulation_results(
-            time=time, results=results, skipfirst=skipfirst
-        )
+        super()._save_simulation_results(time=time, results=results, skipfirst=skipfirst)
         self.simulation_parameters.append(self.model.parameters.copy())
 
     def simulate(self, t_end=None, steps=None, time_points=None, **integrator_kwargs):
@@ -132,14 +135,15 @@ class _Simulate(_BaseSimulator):
         """
         self.model._update_derived_parameters()
         time, results = super().simulate(
-            t_end=t_end, steps=steps, time_points=time_points, **integrator_kwargs,
+            t_end=t_end,
+            steps=steps,
+            time_points=time_points,
+            **integrator_kwargs,
         )
         self.full_results = None
         return time, results
 
-    def simulate_to_steady_state(
-        self, tolerance=1e-8, simulation_kwargs=None, **integrator_kwargs
-    ):
+    def simulate_to_steady_state(self, tolerance=1e-8, simulation_kwargs=None, **integrator_kwargs):
         """Simulate the model to steady state.
 
         Parameters
@@ -176,9 +180,7 @@ class _Simulate(_BaseSimulator):
         m = model.copy()
         s = Sim(model=m, integrator_name=integ_name)
         s.initialise(y0=y0, test_run=False)
-        s.update_parameter(
-            parameter_name=parameter_name, parameter_value=parameter_value
-        )
+        s.update_parameter(parameter_name=parameter_name, parameter_value=parameter_value)
         try:
             t, y = s.simulate_to_steady_state(tolerance=tolerance, **integrator_kwargs)
             return s.get_full_results_array()[-1]
@@ -245,9 +247,7 @@ class _Simulate(_BaseSimulator):
                     ),
                     parameter_values,
                 )
-        return pd.DataFrame(
-            data=results, index=parameter_values, columns=self.model.get_all_compounds()
-        )
+        return pd.DataFrame(data=results, index=parameter_values, columns=self.model.get_all_compounds())
 
     def get_fluxes_array(self, normalise=None, concatenated=True):
         """Get the model fluxes for the simulation.
@@ -263,9 +263,7 @@ class _Simulate(_BaseSimulator):
             fluxes.append(fluxes_array)
 
         if normalise is not None:
-            fluxes = self._normalise_split_array(
-                split_array=fluxes, normalise=normalise
-            )
+            fluxes = self._normalise_split_array(split_array=fluxes, normalise=normalise)
         if concatenated:
             return np.concatenate(fluxes, axis=0)
         else:
@@ -295,11 +293,17 @@ class _Simulate(_BaseSimulator):
         time = self.get_time(concatenated=concatenated)
         if concatenated:
             return pd.DataFrame(
-                data=fluxes, index=self.get_time(), columns=self.model.get_rate_names(),
+                data=fluxes,
+                index=self.get_time(),
+                columns=self.model.get_rate_names(),
             )
         else:
             return [
-                pd.DataFrame(data=flux, index=t, columns=self.model.get_rate_names(),)
+                pd.DataFrame(
+                    data=flux,
+                    index=t,
+                    columns=self.model.get_rate_names(),
+                )
                 for t, flux in zip(time, fluxes)
             ]
 
@@ -309,9 +313,7 @@ class _Simulate(_BaseSimulator):
             self.update_parameters(parameters=p)
             results = self.model.get_full_concentration_dict(y=y, t=t)
             del results["time"]
-            full_results.append(
-                np.reshape(list(results.values()), (len(results), len(t))).T
-            )
+            full_results.append(np.reshape(list(results.values()), (len(results), len(t))).T)
         self.full_results = full_results
 
     def get_full_results_array(self, normalise=None, concatenated=True):
@@ -325,9 +327,7 @@ class _Simulate(_BaseSimulator):
             self._calculate_full_results()
         full_results = self.full_results.copy()
         if normalise is not None:
-            full_results = self._normalise_split_array(
-                split_array=full_results, normalise=normalise
-            )
+            full_results = self._normalise_split_array(split_array=full_results, normalise=normalise)
         if concatenated:
             return np.concatenate(full_results, axis=0)
         else:
@@ -340,15 +340,11 @@ class _Simulate(_BaseSimulator):
         -------
         results : dict
         """
-        full_results = self.get_full_results_array(
-            normalise=normalise, concatenated=concatenated
-        )
+        full_results = self.get_full_results_array(normalise=normalise, concatenated=concatenated)
         if concatenated:
             return dict(zip(self.model.get_all_compounds(), full_results.T))
         else:
-            return [
-                dict(zip(self.model.get_all_compounds(), i.T)) for i in full_results
-            ]
+            return [dict(zip(self.model.get_all_compounds(), i.T)) for i in full_results]
 
     def get_full_results_df(self, normalise=None, concatenated=True):
         """Get simulation results and derived compounds.
@@ -357,15 +353,11 @@ class _Simulate(_BaseSimulator):
         -------
         results : pandas.DataFrame
         """
-        full_results = self.get_full_results_array(
-            normalise=normalise, concatenated=concatenated
-        )
+        full_results = self.get_full_results_array(normalise=normalise, concatenated=concatenated)
         time = self.get_time(concatenated=concatenated)
 
         if concatenated:
-            return pd.DataFrame(
-                data=full_results, index=time, columns=self.model.get_all_compounds()
-            )
+            return pd.DataFrame(data=full_results, index=time, columns=self.model.get_all_compounds())
         else:
             return [
                 pd.DataFrame(data=res, index=t, columns=self.model.get_all_compounds())
@@ -379,9 +371,7 @@ class _Simulate(_BaseSimulator):
         -------
         results : numpy.array
         """
-        full_results_dict = self.get_full_results_dict(
-            normalise=normalise, concatenated=concatenated
-        )
+        full_results_dict = self.get_full_results_dict(normalise=normalise, concatenated=concatenated)
         if concatenated:
             return full_results_dict[variable]
         else:
@@ -394,9 +384,7 @@ class _Simulate(_BaseSimulator):
         -------
         results : tuple(numpy.array)
         """
-        full_results_df = self.get_full_results_df(
-            normalise=normalise, concatenated=concatenated
-        )
+        full_results_df = self.get_full_results_df(normalise=normalise, concatenated=concatenated)
         if concatenated:
             return full_results_df.loc[:, variables].values
         else:
@@ -447,9 +435,7 @@ class _Simulate(_BaseSimulator):
         """
         compounds = self.model.get_compounds()
         x = self.get_time()
-        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[
-            :, compounds
-        ]
+        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[:, compounds]
         return plot(
             plot_args=(x, y),
             legend=compounds,
@@ -469,6 +455,147 @@ class _Simulate(_BaseSimulator):
             title_kwargs=title_kwargs,
         )
 
+    def plot_log(
+        self,
+        xlabel=None,
+        ylabel=None,
+        title=None,
+        normalise=None,
+        grid=True,
+        tight_layout=True,
+        ax=None,
+        figure_kwargs=None,
+        subplot_kwargs=None,
+        plot_kwargs=None,
+        grid_kwargs=None,
+        legend_kwargs=None,
+        tick_kwargs=None,
+        label_kwargs=None,
+        title_kwargs=None,
+    ):
+        """Plot simulation results for a selection of compounds.
+
+        Parameters
+        ----------
+        compounds : iterable(str)
+        xlabel : str
+        ylabel : str
+        title : str
+        grid : bool
+        tight_layout : bool
+        ax : matplotlib axes
+        figure_kwargs : dict
+        subplot_kwargs : dict
+        plot_kwargs : dict
+        grid_kwargs : dict
+        legend_kwargs : dict
+        tick_kwargs : dict
+        label_kwargs : dict
+        title_kwargs : dict
+
+        Returns
+        -------
+        fig : matplotlib Figure
+        ax : matplotlib axes
+        """
+        compounds = self.model.get_compounds()
+        x = self.get_time()
+        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[:, compounds]
+        fig, ax = plot(
+            plot_args=(x, y),
+            legend=compounds,
+            xlabel=xlabel,
+            ylabel=ylabel,
+            title=title,
+            grid=grid,
+            tight_layout=tight_layout,
+            ax=ax,
+            figure_kwargs=figure_kwargs,
+            subplot_kwargs=subplot_kwargs,
+            plot_kwargs=plot_kwargs,
+            grid_kwargs=grid_kwargs,
+            legend_kwargs=legend_kwargs,
+            tick_kwargs=tick_kwargs,
+            label_kwargs=label_kwargs,
+            title_kwargs=title_kwargs,
+        )
+        ax.set_xscale("log")
+        ax.set_yscale("log")
+        return fig, ax
+
+    def plot_semilog(
+        self,
+        log_axis="y",
+        xlabel=None,
+        ylabel=None,
+        title=None,
+        normalise=None,
+        grid=True,
+        tight_layout=True,
+        ax=None,
+        figure_kwargs=None,
+        subplot_kwargs=None,
+        plot_kwargs=None,
+        grid_kwargs=None,
+        legend_kwargs=None,
+        tick_kwargs=None,
+        label_kwargs=None,
+        title_kwargs=None,
+    ):
+        """Plot simulation results for a selection of compounds.
+
+        Parameters
+        ----------
+        compounds : iterable(str)
+        xlabel : str
+        ylabel : str
+        title : str
+        grid : bool
+        tight_layout : bool
+        ax : matplotlib axes
+        figure_kwargs : dict
+        subplot_kwargs : dict
+        plot_kwargs : dict
+        grid_kwargs : dict
+        legend_kwargs : dict
+        tick_kwargs : dict
+        label_kwargs : dict
+        title_kwargs : dict
+
+        Returns
+        -------
+        fig : matplotlib Figure
+        ax : matplotlib axes
+        """
+        compounds = self.model.get_compounds()
+        x = self.get_time()
+        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[:, compounds]
+        fig, ax = plot(
+            plot_args=(x, y),
+            legend=compounds,
+            xlabel=xlabel,
+            ylabel=ylabel,
+            title=title,
+            grid=grid,
+            tight_layout=tight_layout,
+            ax=ax,
+            figure_kwargs=figure_kwargs,
+            subplot_kwargs=subplot_kwargs,
+            plot_kwargs=plot_kwargs,
+            grid_kwargs=grid_kwargs,
+            legend_kwargs=legend_kwargs,
+            tick_kwargs=tick_kwargs,
+            label_kwargs=label_kwargs,
+            title_kwargs=title_kwargs,
+        )
+        if log_axis == "y":
+            ax.set_yscale("log")
+        elif log_axis == "x":
+            ax.set_xscale("log")
+        else:
+            raise ValueError("log_axis must be either x or y")
+        return fig, ax
+
     def plot_derived(
         self,
         xlabel=None,
@@ -513,9 +640,7 @@ class _Simulate(_BaseSimulator):
         """
         compounds = self.model.get_derived_compounds()
         x = self.get_time()
-        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[
-            :, compounds
-        ]
+        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[:, compounds]
         return plot(
             plot_args=(x, y),
             legend=compounds,
@@ -579,9 +704,7 @@ class _Simulate(_BaseSimulator):
         """
         compounds = self.model.get_all_compounds()
         x = self.get_time()
-        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[
-            :, compounds
-        ]
+        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[:, compounds]
         return plot(
             plot_args=(x, y),
             legend=compounds,
@@ -645,9 +768,7 @@ class _Simulate(_BaseSimulator):
         ax : matplotlib axes
         """
         x = self.get_time()
-        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[
-            :, compounds
-        ]
+        y = self.get_full_results_df(normalise=normalise, concatenated=True).loc[:, compounds]
         return plot(
             plot_args=(x, y),
             legend=compounds,
@@ -723,9 +844,7 @@ class _Simulate(_BaseSimulator):
         plot_groups = [
             (
                 time,
-                self.get_full_results_df(normalise=normalise, concatenated=True)
-                .loc[:, compounds]
-                .values,
+                self.get_full_results_df(normalise=normalise, concatenated=True).loc[:, compounds].values,
             )
             for compounds in compound_groups
         ]
@@ -1067,9 +1186,7 @@ class _Simulate(_BaseSimulator):
         """
         rate_names = self.model.get_rate_names()
         x = self.get_time()
-        y = self.get_fluxes_df(normalise=normalise, concatenated=True).loc[
-            :, rate_names
-        ]
+        y = self.get_fluxes_df(normalise=normalise, concatenated=True).loc[:, rate_names]
         return plot(
             plot_args=(x, y),
             legend=rate_names,
@@ -1135,9 +1252,7 @@ class _Simulate(_BaseSimulator):
         ax : matplotlib axes
         """
         x = self.get_time()
-        y = self.get_fluxes_df(normalise=normalise, concatenated=True).loc[
-            :, rate_names
-        ]
+        y = self.get_fluxes_df(normalise=normalise, concatenated=True).loc[:, rate_names]
         return plot(
             plot_args=(x, y),
             legend=rate_names,
@@ -1424,9 +1539,7 @@ class _Simulate(_BaseSimulator):
         kwargs["subplot"].update({"projection": "3d"})
 
         if ax is None:
-            fig, ax = plt.subplots(
-                1, 1, subplot_kw=kwargs["subplot"], **kwargs["figure"]
-            )
+            fig, ax = plt.subplots(1, 1, subplot_kw=kwargs["subplot"], **kwargs["figure"])
         else:
             fig = ax.get_figure()
 
@@ -1532,16 +1645,19 @@ class _Simulate(_BaseSimulator):
                 v[i, j] = rhs[f"d{cpd2}dt"]
 
         if ax is None:
-            fig, ax = plt.subplots(
-                1, 1, subplot_kw=kwargs["subplot"], **kwargs["figure"]
-            )
+            fig, ax = plt.subplots(1, 1, subplot_kw=kwargs["subplot"], **kwargs["figure"])
         else:
             fig = ax.get_figure()
         ax.quiver(x, y, u.T, v.T)
         xlabel = cpd1 if xlabel is None else xlabel
         ylabel = cpd2 if ylabel is None else ylabel
         _style_subplot(
-            ax=ax, xlabel=xlabel, ylabel=ylabel, title=title, grid=grid, kwargs=kwargs,
+            ax=ax,
+            xlabel=xlabel,
+            ylabel=ylabel,
+            title=title,
+            grid=grid,
+            kwargs=kwargs,
         )
         if tight_layout:
             fig.tight_layout()
@@ -1634,9 +1750,7 @@ class _Simulate(_BaseSimulator):
                     w[i, j, k] = rhs[f"d{cpd3}dt"]
 
         if ax is None:
-            fig, ax = plt.subplots(
-                1, 1, subplot_kw=kwargs["subplot"], **kwargs["figure"]
-            )
+            fig, ax = plt.subplots(1, 1, subplot_kw=kwargs["subplot"], **kwargs["figure"])
         else:
             fig = ax.get_figure()
         X, Y, Z = np.meshgrid(x, y, z)
