@@ -1,10 +1,12 @@
 """Write me."""
 
+# Third party
 import numpy as np
 import pandas as pd
 
-from ..__init__ import Simulator
+# Local code
 from ...utils.plotting import heatmap_from_dataframe as _heatmap_from_dataframe
+from ..__init__ import Simulator
 
 _DISPLACEMENT = 1e-4
 
@@ -30,9 +32,7 @@ def _find_steady_state(model, y0):
     return t, y
 
 
-def get_compound_elasticity(
-    model, compound, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_compound_elasticity(model, compound, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get sensitivity of all rates to a change of the concentration of a compound.
 
     Also called epsilon-elasticities. Not in steady state!
@@ -68,9 +68,7 @@ def get_compound_elasticity(
     return np.atleast_1d(np.squeeze(elasticity_coef))
 
 
-def get_compound_elasticities_array(
-    model, compounds, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_compound_elasticities_array(model, compounds, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get sensitivity of all rates to a change of the concentration of multiple compounds.
 
     Also called epsilon-elasticities. Not in steady state!
@@ -89,9 +87,7 @@ def get_compound_elasticities_array(
     -------
     elasticities: numpy.ndarray
     """
-    elasticities = np.full(
-        shape=(len(compounds), len(model.get_rate_names())), fill_value=np.nan
-    )
+    elasticities = np.full(shape=(len(compounds), len(model.get_rate_names())), fill_value=np.nan)
     for i, compound in enumerate(compounds):
         elasticities[i] = get_compound_elasticity(
             model=model,
@@ -104,9 +100,7 @@ def get_compound_elasticities_array(
     return elasticities
 
 
-def get_compound_elasticities_df(
-    model, compounds, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_compound_elasticities_df(model, compounds, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get sensitivity of all rates to a change of the concentration of multiple compounds.
 
     Also called epsilon-elasticities. Not in steady state!
@@ -136,9 +130,7 @@ def get_compound_elasticities_df(
     return pd.DataFrame(data=array, index=compounds, columns=model.get_rate_names())
 
 
-def get_parameter_elasticity(
-    model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_parameter_elasticity(model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get sensitivity of all rates to a change of a parameter value.
 
     Also called pi-elasticities. Not in steady state!
@@ -171,9 +163,7 @@ def get_parameter_elasticity(
     return np.atleast_1d(np.squeeze(elasticity_coef))
 
 
-def get_parameter_elasticities_array(
-    model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_parameter_elasticities_array(model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get sensitivity of all rates to a change of multiple parameter values.
 
     Also called pi-elasticities. Not in steady state!
@@ -192,9 +182,7 @@ def get_parameter_elasticities_array(
     -------
     elasticities: numpy.array
     """
-    elasticities = np.full(
-        shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan
-    )
+    elasticities = np.full(shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan)
     for i, parameter in enumerate(parameters):
         elasticities[i] = get_parameter_elasticity(
             model=model,
@@ -207,9 +195,7 @@ def get_parameter_elasticities_array(
     return elasticities
 
 
-def get_parameter_elasticities_df(
-    model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_parameter_elasticities_df(model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get sensitivity of all rates to a change of multiple parameter values.
 
     Also called pi-elasticities. Not in steady state!
@@ -239,9 +225,7 @@ def get_parameter_elasticities_df(
     return pd.DataFrame(matrix, index=parameters, columns=model.get_rate_names())
 
 
-def get_concentration_response_coefficient(
-    model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_concentration_response_coefficient(model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get response of the steady state concentrations to a change of the given parameter.
 
     Parameters
@@ -295,9 +279,7 @@ def get_concentration_response_coefficients_array(
     -------
     coefficients: numpy.array
     """
-    crs = np.full(
-        shape=(len(parameters), len(model.get_compounds())), fill_value=np.nan
-    )
+    crs = np.full(shape=(len(parameters), len(model.get_compounds())), fill_value=np.nan)
     for i, parameter in enumerate(parameters):
         crs[i] = get_concentration_response_coefficient(
             model=model,
@@ -310,9 +292,7 @@ def get_concentration_response_coefficients_array(
     return crs
 
 
-def get_concentration_response_coefficients_df(
-    model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_concentration_response_coefficients_df(model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get response of the steady state concentrations to a change of the given parameter m.
 
     Parameters
@@ -340,9 +320,7 @@ def get_concentration_response_coefficients_df(
     return pd.DataFrame(data=array, index=parameters, columns=model.get_compounds())
 
 
-def get_flux_response_coefficient(
-    model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_flux_response_coefficient(model, parameter, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get response of the steady state fluxes to a change of the given parameter.
 
     Parameters
@@ -378,9 +356,7 @@ def get_flux_response_coefficient(
     return np.atleast_1d(np.squeeze(resp_coef))
 
 
-def get_flux_response_coefficients_array(
-    model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_flux_response_coefficients_array(model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get response of the steady state fluxes to a change of the given parameters.
 
     Parameters
@@ -397,9 +373,7 @@ def get_flux_response_coefficients_array(
     -------
     coefficients: numpy.array
     """
-    frc = np.full(
-        shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan
-    )
+    frc = np.full(shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan)
     for i, parameter in enumerate(parameters):
         frc[i] = get_flux_response_coefficient(
             model=model,
@@ -412,9 +386,7 @@ def get_flux_response_coefficients_array(
     return frc
 
 
-def get_flux_response_coefficients_df(
-    model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT
-):
+def get_flux_response_coefficients_df(model, parameters, y, t=0, normalized=True, displacement=_DISPLACEMENT):
     """Get response of the steady state fluxes to a change of the given parameters.
 
     Parameters
@@ -483,9 +455,7 @@ def plot_concentration_response_coefficients(
         rows = df.index
     if columns is None:
         columns = df.columns
-    fig, ax, hm = _heatmap_from_dataframe(
-        df.loc[rows, columns], title="Concentration Response Coefficients", ax=ax
-    )
+    fig, ax, hm = _heatmap_from_dataframe(df.loc[rows, columns], title="Concentration Response Coefficients", ax=ax)
     ax.set_xticklabels(ax.get_xticklabels(), **{"rotation": 45, "ha": "right"})
     return fig, ax, hm
 
@@ -531,8 +501,6 @@ def plot_flux_response_coefficients(
         rows = df.index
     if columns is None:
         columns = df.columns
-    fig, ax, hm = _heatmap_from_dataframe(
-        df.loc[rows, columns], title="Flux Response Coefficients", ax=ax
-    )
+    fig, ax, hm = _heatmap_from_dataframe(df.loc[rows, columns], title="Flux Response Coefficients", ax=ax)
     ax.set_xticklabels(ax.get_xticklabels(), **{"rotation": 45, "ha": "right"})
     return fig, ax, hm
