@@ -1,10 +1,13 @@
 """Write me."""
 
-import math
+# Standard Library
 import itertools as it
-import numpy as np
+import math
+
+# Third party
 import matplotlib.pyplot as plt
-from matplotlib.colors import Normalize, LogNorm, SymLogNorm
+import numpy as np
+from matplotlib.colors import LogNorm, Normalize, SymLogNorm
 from matplotlib.colors import colorConverter as _colorConverter
 
 
@@ -275,10 +278,7 @@ def plot_grid(
     """
     if ncols is None:
         _, ncols = min(
-            (
-                (math.ceil(len(plot_groups) / i) * i - len(plot_groups), i)
-                for i in range(2, 6)
-            ),
+            ((math.ceil(len(plot_groups) / i) * i - len(plot_groups), i) for i in range(2, 6)),
             key=lambda x: (x[0], -x[1]),
         )
     nrows = math.ceil(len(plot_groups) / ncols)
@@ -325,9 +325,7 @@ def plot_grid(
         subplot_kw=kwargs["subplot"],
         **kwargs["figure"],
     )
-    for ax, plot_args, legend_args, title in zip(
-        axs.ravel(), plot_groups, legend_groups, plot_titles
-    ):
+    for ax, plot_args, legend_args, title in zip(axs.ravel(), plot_groups, legend_groups, plot_titles):
         ax.plot(*plot_args, **kwargs["plot"])
         ax.set_title(title, **kwargs["title"])
         if legend_args is not None:
@@ -442,12 +440,8 @@ def heatmap_from_dataframe(
         text_kwargs = {"ha": "center", "va": "center"}
         hm.update_scalarmappable()  # So that get_facecolor is an array
         xpos, ypos = np.meshgrid(np.arange(len(columns)), np.arange(len(rows)))
-        for x, y, val, color in zip(
-            xpos.flat, ypos.flat, hm.get_array(), hm.get_facecolor()
-        ):
-            text_kwargs["color"] = (
-                "black" if relative_luminance(color) > 0.45 else "white"
-            )
+        for x, y, val, color in zip(xpos.flat, ypos.flat, hm.get_array(), hm.get_facecolor()):
+            text_kwargs["color"] = "black" if relative_luminance(color) > 0.45 else "white"
             if abs(val) < 100 or abs(val) < 0.01:
                 val_text = f"{val:.2g}"
             else:
